@@ -9,10 +9,11 @@ import os
 import re
 import socket
 
-from . import utils
+from . import utils, sh
 from . import tmpfiles
 from . import parallax
 from . import log
+from .sh import ShellUtils
 
 
 logger = log.setup_logger(__name__)
@@ -31,11 +32,7 @@ def check_tools():
 
 
 def cfgtool(*args):
-    return utils.get_stdout(['corosync-cfgtool'] + list(args), shell=False)
-
-
-def quorumtool(*args):
-    return utils.get_stdout(['corosync-quorumtool'] + list(args), shell=False)
+    return ShellUtils().get_stdout(['corosync-cfgtool'] + list(args), shell=False)
 
 
 def query_status(status_type):
@@ -60,7 +57,7 @@ def query_ring_status():
     """
     Query corosync ring status
     """
-    rc, out, err = utils.get_stdout_stderr("corosync-cfgtool -s")
+    rc, out, err = ShellUtils().get_stdout_stderr("corosync-cfgtool -s")
     if rc != 0 and err:
         raise ValueError(err)
     if out:
@@ -73,7 +70,7 @@ def query_quorum_status():
 
     """
     utils.print_cluster_nodes()
-    rc, out, err = utils.get_stdout_stderr("corosync-quorumtool -s")
+    rc, out, err = ShellUtils().get_stdout_stderr("corosync-quorumtool -s")
     if rc != 0 and err:
         raise ValueError(err)
     # If the return code of corosync-quorumtool is 2,
@@ -89,7 +86,7 @@ def query_qdevice_status():
     if not utils.is_qdevice_configured():
         raise ValueError("QDevice/QNetd not configured!")
     cmd = "corosync-qdevice-tool -sv"
-    out = utils.get_stdout_or_raise_error(cmd)
+    out = sh.cluster_shell().get_stdout_or_raise_error(cmd)
     utils.print_cluster_nodes()
     print(out)
 
@@ -368,13 +365,6 @@ class Parser(object):
         return ''.join(joiner(self._tokens))
 
 
-def logfile(conftext):
-    '''
-    Return corosync logfile (if set)
-    '''
-    return Parser(conftext).get('logging.logfile')
-
-
 def push_configuration(nodes):
     '''
     Push the local configuration to the list of remote nodes
@@ -618,7 +608,7 @@ _COROSYNC_CONF_TEMPLATE_TAIL = """
 logging {
     fileline:   off
     to_stderr:  no
-    to_logfile:     no
+    to_logfile: yes
     logfile:    /var/log/cluster/corosync.log
     to_syslog:  yes
     debug:      off
@@ -763,7 +753,7 @@ def get_corosync_value(key):
     Get corosync configuration value from corosync-cmapctl or corosync.conf
     """
     try:
-        out = utils.get_stdout_or_raise_error("corosync-cmapctl {}".format(key))
+        out = sh.cluster_shell().get_stdout_or_raise_error("corosync-cmapctl {}".format(key))
         res = re.search(r'{}\s+.*=\s+(.*)'.format(key), out)
         return res.group(1) if res else None
     except ValueError:
