@@ -5,9 +5,11 @@ import re
 from . import config
 from . import tmpfiles
 from . import utils
-from .msg import common_err
 from .ordereddict import odict
+from . import log
 
+
+logger = log.setup_logger(__name__)
 # graphviz stuff
 
 
@@ -195,7 +197,7 @@ class GvDot(Gv):
 
     def display(self):
         if not config.core.dotty:
-            common_err("dotty not found")
+            logger.error("dotty not found")
             return False
         dotf = self.totmpf()
         if not dotf:
@@ -205,7 +207,7 @@ class GvDot(Gv):
 
     def image(self, img_type, outf):
         if not config.core.dot:
-            common_err("dot not found")
+            logger.error("dot not found")
             return False
         dotf = self.totmpf()
         if not dotf:
