@@ -6,9 +6,10 @@ import re
 import time
 from contextlib import contextmanager
 
-from . import utils
+from . import sh
 from . import config
 from . import log
+from .sh import ShellUtils
 
 
 logger = log.setup_logger(__name__)
@@ -31,7 +32,7 @@ class Lock(object):
     A base class define a lock mechanism used to exclude other nodes
     """
 
-    LOCK_DIR_NON_PRIVILEGED = "/tmp/.crmsh_lock_directory"
+    LOCK_DIR_DEFAULT = "/run/.crmsh_lock_directory"
 
     def __init__(self, lock_dir=None):
         """
@@ -39,13 +40,13 @@ class Lock(object):
         """
         # only the lock owner can unlock
         self.lock_owner = False
-        self.lock_dir = lock_dir or self.LOCK_DIR_NON_PRIVILEGED
+        self.lock_dir = lock_dir or self.LOCK_DIR_DEFAULT
 
     def _run(self, cmd):
         """
         Run command on local
         """
-        return utils.get_stdout_stderr(cmd)
+        return ShellUtils().get_stdout_stderr(cmd)
 
     def _create_lock_dir(self):
         """
@@ -115,7 +116,7 @@ class RemoteLock(Lock):
         Run command on remote node
         """
         # TODO: pass SSH_OPTION
-        rc, out, err = utils.run_cmd_on_remote(cmd, self.remote_node)
+        rc, out, err = sh.cluster_shell().get_rc_stdout_stderr_without_input(self.remote_node, cmd)
         if rc == self.SSH_EXIT_ERR:
             raise SSHError(err)
         return rc, out, err
