@@ -6,7 +6,9 @@ import subprocess
 import tempfile
 import typing
 from enum import Enum
-from . import constants
+
+import crmsh.parallax
+from . import constants, sh
 from . import utils
 from . import parallax
 from . import corosync
@@ -14,7 +16,7 @@ from . import xmlutil
 from . import bootstrap
 from . import lock
 from . import log
-
+from .service_manager import ServiceManager
 
 logger = log.setup_logger(__name__)
 logger_utils = log.LoggerUtils(logger)
@@ -50,7 +52,7 @@ def evaluate_qdevice_quorum_effect(mode, diskless_sbd=False, is_stage=False):
     elif mode == QDEVICE_ADD and not is_stage:
         # Add qdevice from init process, safe to restart
         return QdevicePolicy.QDEVICE_RESTART
-    elif xmlutil.CrmMonXmlParser.is_any_resource_running():
+    elif xmlutil.CrmMonXmlParser().is_any_resource_running():
         # will lose quorum, and with RA running
         # no reload, no restart cluster service
         # just leave a warning
@@ -293,17 +295,18 @@ class QDevice(object):
         exception_msg = ""
         suggest = ""
         duplicated_cluster_name = False
+        shell = sh.cluster_shell()
         if not utils.package_is_installed("corosync-qnetd", remote_addr=self.qnetd_addr):
             exception_msg = "Package \"corosync-qnetd\" not installed on {}!".format(self.qnetd_addr)
             suggest = "install \"corosync-qnetd\" on {}".format(self.qnetd_addr)
-        elif utils.service_is_active("corosync-qnetd", remote_addr=self.qnetd_addr):
+        elif ServiceManager().service_is_active("corosync-qnetd", remote_addr=self.qnetd_addr):
             cmd = "corosync-qnetd-tool -l -c {}".format(self.cluster_name)
-            if utils.get_stdout_or_raise_error(cmd, remote=self.qnetd_addr):
+            if shell.get_stdout_or_raise_error(cmd, self.qnetd_addr):
                 duplicated_cluster_name = True
         else:
             cmd = "test -f {}".format(self.qnetd_cluster_crt_on_qnetd)
             try:
-                utils.get_stdout_or_raise_error(cmd, remote=self.qnetd_addr)
+                shell.get_stdout_or_raise_error(cmd, self.qnetd_addr)
             except ValueError:
                 # target file not exist
                 pass
@@ -321,16 +324,16 @@ class QDevice(object):
             raise ValueError(exception_msg)
 
     def enable_qnetd(self):
-        utils.enable_service(self.qnetd_service, remote_addr=self.qnetd_addr)
+        ServiceManager().enable_service(self.qnetd_service, remote_addr=self.qnetd_addr)
 
     def disable_qnetd(self):
-        utils.disable_service(self.qnetd_service, remote_addr=self.qnetd_addr)
+        ServiceManager().disable_service(self.qnetd_service, remote_addr=self.qnetd_addr)
 
     def start_qnetd(self):
-        utils.start_service(self.qnetd_service, remote_addr=self.qnetd_addr)
+        ServiceManager().start_service(self.qnetd_service, remote_addr=self.qnetd_addr)
 
     def stop_qnetd(self):
-        utils.stop_service(self.qnetd_service, remote_addr=self.qnetd_addr)
+        ServiceManager().stop_service(self.qnetd_service, remote_addr=self.qnetd_addr)
 
     def set_cluster_name(self):
         if not self.cluster_name:
@@ -370,7 +373,7 @@ class QDevice(object):
 
         desc = "Step 2: Fetch {} from {}".format(self.qnetd_cacert_filename, self.qnetd_addr)
         QDevice.log_only_to_file(desc)
-        self._fetch_file_to_local(self.qnetd_addr, self.qnetd_cacert_on_qnetd, '{}/{}'.format(self.qdevice_path, self.qnetd_addr))
+        crmsh.parallax.parallax_slurp([self.qnetd_addr], self.qdevice_path, self.qnetd_cacert_on_qnetd)
 
     def copy_qnetd_crt_to_cluster(self):
         """
@@ -384,30 +387,11 @@ class QDevice(object):
 
         desc = "Step 3: Copy exported {} to {}".format(self.qnetd_cacert_filename, node_list)
         QDevice.log_only_to_file(desc)
-        self._copy_file_to_remote_hosts(os.path.dirname(self.qnetd_cacert_on_local), node_list, self.qdevice_path)
-
-    @classmethod
-    def _copy_file_to_remote_host(cls, local_file, remote_host: str, remote_path):
-        local_user, remote_user = utils.user_pair_for_ssh(remote_host)
-        with tempfile.NamedTemporaryFile('w', encoding='utf-8') as tmp:
-            tmp.write("put -pr '{}' '{}'\n".format(local_file, remote_path))
-            tmp.flush()
-            # we can not su to a non-root user, since reading the source file may need privilege.
-            cmd = "sftp {} -o IdentityFile=~{}/.ssh/id_rsa -o BatchMode=yes -s 'sudo PATH=/usr/lib/ssh:/usr/libexec/ssh /bin/sh -c \"exec sftp-server\"' -b {} {}@{}".format(
-                constants.SSH_OPTION,
-                local_user,
-                # FIXME: sftp-server is not always in /usr/lib/ssh
-                tmp.name,
-                remote_user, cls._enclose_inet6_addr(remote_host),
-            )
-            result = subprocess.run(
-                ['/bin/sh', '-c', cmd],
-                stdin=subprocess.DEVNULL,
-                stdout=subprocess.PIPE,
-                stderr=subprocess.STDOUT,
-            )
-        if result.returncode != 0:
-            utils.fatal('Failed to copy file from {} to {}:{}: {}: {}'.format(local_file, remote_host, remote_path, cmd, utils.to_ascii(result.stdout)))
+        self._copy_file_to_remote_hosts(
+            os.path.dirname(self.qnetd_cacert_on_local),
+            node_list, self.qdevice_path,
+            recursive=True,
+        )
 
     @staticmethod
     def _enclose_inet6_addr(addr: str):
@@ -417,9 +401,8 @@ class QDevice(object):
             return addr
 
     @classmethod
-    def _copy_file_to_remote_hosts(cls, local_file, remote_hosts: typing.Iterable[str], remote_path):
-        for host in remote_hosts:
-            cls._copy_file_to_remote_host(local_file, host, remote_path)
+    def _copy_file_to_remote_hosts(cls, local_file, remote_hosts: typing.Iterable[str], remote_path, recursive=False):
+        crmsh.parallax.parallax_copy(remote_hosts, local_file, remote_path, recursive)
 
     def init_db_on_cluster(self):
         """
@@ -432,7 +415,7 @@ class QDevice(object):
         cmd = "corosync-qdevice-net-certutil -i -c {}".format(self.qnetd_cacert_on_local)
         desc = "Step 4: Initialize database on {}".format(node_list)
         QDevice.log_only_to_file(desc, cmd)
-        parallax.parallax_call(node_list, cmd)
+        crmsh.parallax.parallax_call(node_list, cmd)
 
     def create_ca_request(self):
         """
@@ -444,7 +427,7 @@ class QDevice(object):
         """
         cmd = "corosync-qdevice-net-certutil -r -n {}".format(self.cluster_name)
         QDevice.log_only_to_file("Step 5: Generate certificate request {}".format(self.qdevice_crq_filename), cmd)
-        utils.get_stdout_or_raise_error(cmd)
+        sh.cluster_shell().get_stdout_or_raise_error(cmd)
 
     def copy_crq_to_qnetd(self):
         """
@@ -454,7 +437,7 @@ class QDevice(object):
         """
         desc = "Step 6: Copy {} to {}".format(self.qdevice_crq_filename, self.qnetd_addr)
         QDevice.log_only_to_file(desc)
-        self._copy_file_to_remote_host(self.qdevice_crq_on_local, self.qnetd_addr, self.qdevice_crq_on_qnetd)
+        self._copy_file_to_remote_hosts(self.qdevice_crq_on_local, [self.qnetd_addr], self.qdevice_crq_on_qnetd)
 
     def sign_crq_on_qnetd(self):
         """
@@ -477,21 +460,7 @@ class QDevice(object):
         """
         desc = "Step 8: Fetch {} from {}".format(os.path.basename(self.qnetd_cluster_crt_on_qnetd), self.qnetd_addr)
         QDevice.log_only_to_file(desc)
-        self._fetch_file_to_local(self.qnetd_addr, self.qnetd_cluster_crt_on_qnetd, '{}/{}'.format(self.qdevice_path, self.qnetd_addr))
-
-    @classmethod
-    def _fetch_file_to_local(cls, remote_host: str, remote_path: str, local_dir: str):
-        basename = os.path.basename(remote_path)
-        rc, stdout, stderr = utils.get_stdout_stderr_auto_ssh_no_input(
-            remote_host,
-            "cat '{}'".format(remote_path),
-            raw=True,
-        )
-        if rc != 0:
-            utils.fatal("Failed to fetch file {} from {}: {}".format(remote_path, remote_host, stderr))
-        os.makedirs(local_dir, exist_ok=True)
-        with open('{}/{}'.format(local_dir, basename), 'wb') as f:
-            f.write(stdout)
+        crmsh.parallax.parallax_slurp([self.qnetd_addr], self.qdevice_path, self.qnetd_cluster_crt_on_qnetd)
 
     def import_cluster_crt(self):
         """
@@ -504,7 +473,7 @@ class QDevice(object):
         QDevice.log_only_to_file(
                 "Step 9: Import certificate file {} on local".format(os.path.basename(self.qnetd_cluster_crt_on_local)),
                 cmd)
-        utils.get_stdout_or_raise_error(cmd)
+        sh.cluster_shell().get_stdout_or_raise_error(cmd)
 
     def copy_p12_to_cluster(self):
         """
@@ -563,7 +532,7 @@ class QDevice(object):
 
         desc = "Step 1: Fetch {} from {}".format(self.qnetd_cacert_filename, self.cluster_node)
         QDevice.log_only_to_file(desc)
-        self._fetch_file_to_local(self.cluster_node, self.qnetd_cacert_on_local, '{}/{}'.format(self.qdevice_path, self.cluster_node))
+        crmsh.parallax.parallax_slurp([self.cluster_node], self.qdevice_path, self.qnetd_cacert_on_local)
 
     def init_db_on_local(self):
         """
@@ -577,7 +546,7 @@ class QDevice(object):
 
         cmd = "corosync-qdevice-net-certutil -i -c {}".format(self.qnetd_cacert_on_cluster)
         QDevice.log_only_to_file("Step 2: Initialize database on local", cmd)
-        utils.get_stdout_or_raise_error(cmd)
+        sh.cluster_shell().get_stdout_or_raise_error(cmd)
 
     def fetch_p12_from_cluster(self):
         """
@@ -590,7 +559,7 @@ class QDevice(object):
 
         desc = "Step 3: Fetch {} from {}".format(self.qdevice_p12_filename, self.cluster_node)
         QDevice.log_only_to_file(desc)
-        self._fetch_file_to_local(self.cluster_node, self.qdevice_p12_on_local, '{}/{}'.format(self.qdevice_path, self.cluster_node))
+        crmsh.parallax.parallax_slurp([self.cluster_node], self.qdevice_path, self.qdevice_p12_on_local)
 
     def import_p12_on_local(self):
         """
@@ -600,7 +569,7 @@ class QDevice(object):
         """
         cmd = "corosync-qdevice-net-certutil -m -c {}".format(self.qdevice_p12_on_cluster)
         QDevice.log_only_to_file("Step 4: Import cluster certificate and key", cmd)
-        utils.get_stdout_or_raise_error(cmd)
+        sh.cluster_shell().get_stdout_or_raise_error(cmd)
 
     def certificate_process_on_join(self):
         """
@@ -666,10 +635,11 @@ class QDevice(object):
         qnetd_host = corosync.get_value('quorum.device.net.host')
         cluster_name = corosync.get_value('totem.cluster_name')
         cls_inst = cls(qnetd_host, cluster_name=cluster_name)
+        shell = sh.cluster_shell()
         cmd = "test -f {crt_file} && rm -f {crt_file}".format(crt_file=cls_inst.qnetd_cluster_crt_on_qnetd)
-        utils.get_stdout_or_raise_error(cmd, remote=qnetd_host)
+        shell.get_stdout_or_raise_error(cmd, qnetd_host)
         cmd = "test -f {crq_file} && rm -f {crq_file}".format(crq_file=cls_inst.qdevice_crq_on_qnetd)
-        utils.get_stdout_or_raise_error(cmd, remote=qnetd_host)
+        shell.get_stdout_or_raise_error(cmd, qnetd_host)
 
     def config_qdevice(self):
         """
@@ -738,7 +708,7 @@ class QDevice(object):
         """
         Check if qdevice can contribute vote
         """
-        out = utils.get_stdout_or_raise_error("corosync-quorumtool -s", success_val_list=[0, 2])
+        out = sh.cluster_shell().get_stdout_or_raise_error("corosync-quorumtool -s", success_exit_status={0, 2})
         res = re.search(r'\s+0\s+0\s+Qdevice', out)
         if res:
             qnetd_host = corosync.get_value('quorum.device.net.host')
