@@ -4,10 +4,12 @@
 
 import sys
 import re
+import argparse
+import typing
 from argparse import ArgumentParser, RawDescriptionHelpFormatter
 
 import crmsh.parallax
-from . import command
+from . import command, sh
 from . import utils
 from . import scripts
 from . import completers as compl
@@ -15,6 +17,9 @@ from . import bootstrap
 from . import corosync
 from . import qdevice
 from .cibconfig import cib_factory
+from .prun import prun
+from .service_manager import ServiceManager
+from .sh import ShellUtils
 from .ui_node import parse_option_for_nodes
 from . import constants
 
@@ -31,7 +36,7 @@ def parse_options(parser, args):
     if hasattr(options, 'help') and options.help:
         parser.print_help()
         return None, None
-    utils.check_space_option_value(options)
+    utils.check_empty_option_value(options)
     return options, args
 
 
@@ -58,7 +63,7 @@ def script_args(args):
 
 def get_cluster_name():
     cluster_name = None
-    if not utils.service_is_active("corosync.service"):
+    if not ServiceManager(sh.ClusterShellAdaptorForLocalShell(sh.LocalShell())).service_is_active("corosync.service"):
         name = corosync.get_values('totem.cluster_name')
         if name:
             cluster_name = name[0]
@@ -67,6 +72,77 @@ def get_cluster_name():
     return cluster_name
 
 
+class ArgparseCustomizableAction(argparse.Action):
+    def __call__(self, parser, namespace, value, option_string=None):
+        previous_value = getattr(namespace, self.dest, None)
+        parsed_value = self.parse(parser, previous_value, value, option_string=None)
+        self.validate(parser, parsed_value, option_string)
+        setattr(namespace, self.dest, parsed_value)
+
+    def parse(self, parser, previous_value, raw_value, option_string):
+        """Parse one argument and return the parsed value.
+
+        Arguments:
+            previous_value: The previous value hold in the destinating attribute.
+            raw_value: The string value to be parse.
+            option_string: The command-line option string associated with this action.
+        """
+        raise NotImplementedError
+
+    def validate(self, parser, parsed_value, option_string):
+        pass
+
+
+class ArgparseActionSplitAndAppendParseMixin(ArgparseCustomizableAction):
+    """Parse `--foo a;b --foo "c d" --foo e` into ['a', 'b', 'c', 'd', 'e']"""
+    def parse(self, parser, previous_value, raw_value, option_string):
+        items = previous_value if previous_value is not None else []
+        items.extend([x for x in re.split("[; ]", raw_value) if x])
+        return items
+
+
+class ArgparseActionUniqueListItemValidateMixin(ArgparseCustomizableAction):
+    """Validate te uniqueness of parsed list items."""
+    def validate(self, parser, parsed_value, option_string):
+        if len(parsed_value) != len(set(parsed_value)):
+            parser.error(f"Duplicated input for '{'/'.join(self.option_strings)}' option")
+
+
+class CustomAppendAction(ArgparseActionSplitAndAppendParseMixin, ArgparseActionUniqueListItemValidateMixin):
+    """
+    Custom class for argparse append action:
+    - Flatten the value like '-s "/dev/sda1;/dev/sda2"'
+    - Detect duplicated input
+    """
+    pass
+
+
+class ArgparseActionUniqueHostInListItemValidateMixin(ArgparseCustomizableAction):
+    """Validate the uniqueness of hosts in a parsed list in the format of 'user@host'"""
+    def validate(self, parser, parsed_value, option_string):
+        known_hosts = set()
+        for item in parsed_value:
+            match = re.match("^(?:[^@]+@)?([^@]+)$", item)
+            if match is None:
+                parser.error("Malformed value for option {} [<user>@]<host>: {}.".format(
+                    '/'.join(self.option_strings), parsed_value
+                ))
+            host = match.group(1)
+            if host in known_hosts:
+                parser.error("Duplicated host in option {}: {}".format(
+                    '/'.join(self.option_strings), parsed_value
+                ))
+            known_hosts.add(host)
+
+
+class ArgparseUserAtHostAppendAction(
+    ArgparseActionSplitAndAppendParseMixin,
+    ArgparseActionUniqueHostInListItemValidateMixin,
+):
+    pass
+
+
+
 class Cluster(command.UI):
     '''
     Whole cluster management.
@@ -100,64 +176,101 @@ class Cluster(command.UI):
             start_qdevice = True
             service_check_list.append("corosync-qdevice.service")
 
+        service_manager = ServiceManager()
         node_list = parse_option_for_nodes(context, *args)
         for node in node_list[:]:
-            if all([utils.service_is_active(srv, remote_addr=node) for srv in service_check_list]):
+            if all([service_manager.service_is_active(srv, remote_addr=node) for srv in service_check_list]):
                 logger.info("The cluster stack already started on {}".format(node))
                 node_list.remove(node)
         if not node_list:
             return
 
         if start_qdevice:
-            utils.start_service("corosync-qdevice", node_list=node_list)
+            service_manager.start_service("corosync-qdevice", node_list=node_list)
         node_list = bootstrap.start_pacemaker(node_list)
         if start_qdevice:
             qdevice.QDevice.check_qdevice_vote()
         for node in node_list:
             logger.info("The cluster stack started on {}".format(node))
 
+    @staticmethod
+    def _node_ready_to_stop_cluster_service(node):
+        """
+        Check if the specific node is ready to stop cluster service
+
+        If both corosync.service and pacemaker.service is active, return True
+        If some services started, stop them first and return False
+        """
+        service_manager = ServiceManager()
+
+        corosync_active = service_manager.service_is_active("corosync.service", remote_addr=node)
+        sbd_active = service_manager.service_is_active("sbd.service", remote_addr=node)
+        pacemaker_active = service_manager.service_is_active("pacemaker.service", remote_addr=node)
+
+        if not corosync_active:
+            if sbd_active:
+                service_manager.stop_service("corosync", remote_addr=node)
+                logger.info(f"The cluster stack stopped on {node}")
+            else:
+                logger.info(f"The cluster stack already stopped on {node}")
+            return False
+
+        elif not pacemaker_active:
+            service_manager.stop_service("corosync", remote_addr=node)
+            logger.info("The cluster stack stopped on {}".format(node))
+            return False
+
+        return True
+
+    @staticmethod
+    def _wait_for_dc(node=None):
+        """
+        Wait for the cluster's DC to become available
+        """
+        if not ServiceManager().service_is_active("pacemaker.service", remote_addr=node):
+            return
+
+        dc_deadtime = utils.get_property("dc-deadtime", peer=node) or str(constants.DC_DEADTIME_DEFAULT)
+        dc_timeout = int(dc_deadtime.strip('s')) + 5
+        try:
+            utils.check_function_with_timeout(utils.get_dc, wait_timeout=dc_timeout, peer=node)
+        except TimeoutError:
+            logger.error("No DC found currently, please wait if the cluster is still starting")
+            raise utils.TerminateSubCommand
+
+    @staticmethod
+    def _set_dlm(node=None):
+        """
+        When dlm running and quorum is lost, before stop cluster service, should set
+        enable_quorum_fencing=0, enable_quorum_lockspace=0 for dlm config option
+        """
+        if utils.is_dlm_running(node) and not utils.is_quorate(node):
+            logger.debug("Quorum is lost; Set enable_quorum_fencing=0 and enable_quorum_lockspace=0 for dlm")
+            utils.set_dlm_option(peer=node, enable_quorum_fencing=0, enable_quorum_lockspace=0)
+
     @command.skill_level('administrator')
     def do_stop(self, context, *args):
         '''
         Stops the cluster stack on all nodes or specific node(s)
         '''
         node_list = parse_option_for_nodes(context, *args)
-        for node in node_list[:]:
-            if not utils.service_is_active("corosync.service", remote_addr=node):
-                if utils.service_is_active("sbd.service", remote_addr=node):
-                    utils.stop_service("corosync", remote_addr=node)
-                    logger.info("The cluster stack stopped on {}".format(node))
-                else:
-                    logger.info("The cluster stack already stopped on {}".format(node))
-                node_list.remove(node)
-            elif not utils.service_is_active("pacemaker.service", remote_addr=node):
-                utils.stop_service("corosync", remote_addr=node)
-                logger.info("The cluster stack stopped on {}".format(node))
-                node_list.remove(node)
+        node_list = [n for n in node_list if self._node_ready_to_stop_cluster_service(n)]
         if not node_list:
             return
+        logger.debug(f"stop node list: {node_list}")
 
-        dc_deadtime = utils.get_property("dc-deadtime") or str(constants.DC_DEADTIME_DEFAULT)
-        dc_timeout = int(dc_deadtime.strip('s')) + 5
-        try:
-            utils.check_function_with_timeout(utils.get_dc, wait_timeout=dc_timeout)
-        except TimeoutError:
-            logger.error("No DC found currently, please wait if the cluster is still starting")
-            return False
+        self._wait_for_dc(node_list[0])
 
-        # When dlm running and quorum is lost, before stop cluster service, should set
-        # enable_quorum_fencing=0, enable_quorum_lockspace=0 for dlm config option
-        if utils.is_dlm_running() and not utils.is_quorate():
-            logger.debug("Quorum is lost; Set enable_quorum_fencing=0 and enable_quorum_lockspace=0 for dlm")
-            utils.set_dlm_option(enable_quorum_fencing=0, enable_quorum_lockspace=0)
+        self._set_dlm(node_list[0])
 
+        service_manager = ServiceManager()
         # Stop pacemaker since it can make sure cluster has quorum until stop corosync
-        node_list = utils.stop_service("pacemaker", node_list=node_list)
+        node_list = service_manager.stop_service("pacemaker", node_list=node_list)
         # Then, stop qdevice if is active
-        if utils.service_is_active("corosync-qdevice.service"):
-            utils.stop_service("corosync-qdevice.service", node_list=node_list)
+        if service_manager.service_is_active("corosync-qdevice.service"):
+            service_manager.stop_service("corosync-qdevice.service", node_list=node_list)
         # Last, stop corosync
-        node_list = utils.stop_service("corosync", node_list=node_list)
+        node_list = service_manager.stop_service("corosync", node_list=node_list)
 
         for node in node_list:
             logger.info("The cluster stack stopped on {}".format(node))
@@ -177,9 +290,10 @@ class Cluster(command.UI):
         Enable the cluster services on this node
         '''
         node_list = parse_option_for_nodes(context, *args)
-        node_list = utils.enable_service("pacemaker.service", node_list=node_list)
-        if utils.service_is_available("corosync-qdevice.service") and utils.is_qdevice_configured():
-            utils.enable_service("corosync-qdevice.service", node_list=node_list)
+        service_manager = ServiceManager()
+        node_list = service_manager.enable_service("pacemaker.service", node_list=node_list)
+        if service_manager.service_is_available("corosync-qdevice.service") and utils.is_qdevice_configured():
+            service_manager.enable_service("corosync-qdevice.service", node_list=node_list)
         for node in node_list:
             logger.info("Cluster services enabled on %s", node)
 
@@ -189,8 +303,9 @@ class Cluster(command.UI):
         Disable the cluster services on this node
         '''
         node_list = parse_option_for_nodes(context, *args)
-        node_list = utils.disable_service("pacemaker.service", node_list=node_list)
-        utils.disable_service("corosync-qdevice.service", node_list=node_list)
+        service_manager = ServiceManager()
+        node_list = service_manager.disable_service("pacemaker.service", node_list=node_list)
+        service_manager.disable_service("corosync-qdevice.service", node_list=node_list)
         for node in node_list:
             logger.info("Cluster services disabled on %s", node)
 
@@ -265,12 +380,18 @@ Examples:
   # Setup the cluster on the current node, with SBD+OCFS2
   crm cluster init -s <share disk1> -o <share disk2> -y
 
-  # Setup the cluster on the current node, with SBD++OCFS2++Cluster LVM
+  # Setup the cluster on the current node, with SBD+OCFS2+Cluster LVM
   crm cluster init -s <share disk1> -o <share disk2> -o <share disk3> -C -y
 
   # Add SBD on a running cluster
   crm cluster init sbd -s <share disk> -y
 
+  # Replace SBD device on a running cluster which already configured SBD
+  crm -F cluster init sbd -s <share disk> -y
+
+  # Add diskless SBD on a running cluster
+  crm cluster init sbd -S -y
+
   # Add QDevice on a running cluster
   crm cluster init qdevice --qnetd-hostname <qnetd addr> -y
 
@@ -285,7 +406,7 @@ Examples:
                             help='Answer "yes" to all prompts (use with caution, this is destructive, especially those storage related configurations and stages.)')
         parser.add_argument("-n", "--name", metavar="NAME", dest="cluster_name", default="hacluster",
                             help='Set the name of the configured cluster.')
-        parser.add_argument("-N", "--node", metavar="NODENAME", dest="node_list", action="append", default=[],
+        parser.add_argument("-N", "--node", metavar="[USER@]HOST", dest="user_at_node_list", action=ArgparseUserAtHostAppendAction, default=[],
                             help='The member node of the cluster. Note: the current node is always get initialized during bootstrap in the beginning.')
         parser.add_argument("-S", "--enable-sbd", dest="diskless_sbd", action="store_true",
                             help="Enable SBD even if no SBD device is configured (diskless mode)")
@@ -295,9 +416,11 @@ Examples:
                             help="Skip csync2 initialization (an experimental option)")
         parser.add_argument("--no-overwrite-sshkey", action="store_true", dest="no_overwrite_sshkey",
                             help='Avoid "/root/.ssh/id_rsa" overwrite if "-y" option is used (False by default; Deprecated)')
+        parser.add_argument('--use-ssh-agent', action='store_true', dest='use_ssh_agent',
+                            help="Use an existing key from ssh-agent instead of creating new key pairs")
 
         network_group = parser.add_argument_group("Network configuration", "Options for configuring the network and messaging layer.")
-        network_group.add_argument("-i", "--interface", dest="nic_list", metavar="IF", action="append", choices=utils.interface_choice(), default=[],
+        network_group.add_argument("-i", "--interface", dest="nic_list", metavar="IF", action=CustomAppendAction, choices=utils.interface_choice(), default=[],
                                    help="Bind to IP address on interface IF. Use -i second time for second interface")
         network_group.add_argument("-u", "--unicast", action="store_true", dest="unicast",
                                    help="Configure corosync to communicate over unicast(udpu). This is the default transport type")
@@ -311,8 +434,8 @@ Examples:
                                    help="Configure corosync use IPv6")
 
         qdevice_group = parser.add_argument_group("QDevice configuration", re.sub('  ', '', constants.QDEVICE_HELP_INFO) + "\n\nOptions for configuring QDevice and QNetd.")
-        qdevice_group.add_argument("--qnetd-hostname", dest="qnetd_addr", metavar="HOST",
-                                   help="HOST or IP of the QNetd server to be used")
+        qdevice_group.add_argument("--qnetd-hostname", dest="qnetd_addr", metavar="[USER@]HOST",
+                                   help="User and host of the QNetd server. The host can be specified in either hostname or IP address.")
         qdevice_group.add_argument("--qdevice-port", dest="qdevice_port", metavar="PORT", type=int, default=5403,
                                    help="TCP PORT of QNetd server (default:5403)")
         qdevice_group.add_argument("--qdevice-algo", dest="qdevice_algo", metavar="ALGORITHM", default="ffsplit", choices=['ffsplit', 'lms'],
@@ -327,9 +450,9 @@ Examples:
                                    help="MODE of operation of heuristics (on/sync/off, default:sync)")
 
         storage_group = parser.add_argument_group("Storage configuration", "Options for configuring shared storage.")
-        storage_group.add_argument("-s", "--sbd-device", dest="sbd_devices", metavar="DEVICE", action="append", default=[],
+        storage_group.add_argument("-s", "--sbd-device", dest="sbd_devices", metavar="DEVICE", action=CustomAppendAction, default=[],
                                    help="Block device to use for SBD fencing, use \";\" as separator or -s multiple times for multi path (up to 3 devices)")
-        storage_group.add_argument("-o", "--ocfs2-device", dest="ocfs2_devices", metavar="DEVICE", action="append", default=[],
+        storage_group.add_argument("-o", "--ocfs2-device", dest="ocfs2_devices", metavar="DEVICE", action=CustomAppendAction, default=[],
                 help="Block device to use for OCFS2; When using Cluster LVM2 to manage the shared storage, user can specify one or multiple raw disks, use \";\" as separator or -o multiple times for multi path (must specify -C option) NOTE: this is a Technical Preview")
         storage_group.add_argument("-C", "--cluster-lvm2", action="store_true", dest="use_cluster_lvm2",
                 help="Use Cluster LVM2 (only valid together with -o option) NOTE: this is a Technical Preview")
@@ -350,7 +473,7 @@ Examples:
             parser.error("Invalid stage (%s)" % (stage))
 
         if options.qnetd_addr:
-            if not utils.service_is_available("corosync-qdevice.service"):
+            if not ServiceManager().service_is_available("corosync-qdevice.service"):
                 utils.fatal("corosync-qdevice.service is not available")
             if options.qdevice_heuristics_mode and not options.qdevice_heuristics:
                 parser.error("Option --qdevice-heuristics is required if want to configure heuristics mode")
@@ -364,7 +487,7 @@ Examples:
         boot_context.ui_context = context
         boot_context.stage = stage
         boot_context.args = args
-        boot_context.cluster_is_running = utils.service_is_active("pacemaker.service")
+        boot_context.cluster_is_running = ServiceManager(sh.ClusterShellAdaptorForLocalShell(sh.LocalShell())).service_is_active("pacemaker.service")
         boot_context.type = "init"
         boot_context.initialize_qdevice()
         boot_context.validate_option()
@@ -405,10 +528,15 @@ Examples:
         parser.add_argument("-q", "--quiet", help="Be quiet (don't describe what's happening, just do it)", action="store_true", dest="quiet")
         parser.add_argument("-y", "--yes", help='Answer "yes" to all prompts (use with caution)', action="store_true", dest="yes_to_all")
         parser.add_argument("-w", "--watchdog", dest="watchdog", metavar="WATCHDOG", help="Use the given watchdog device")
+        parser.add_argument('--use-ssh-agent', action='store_true', dest='use_ssh_agent',
+                            help="Use an existing key from ssh-agent instead of creating new key pairs")
 
         network_group = parser.add_argument_group("Network configuration", "Options for configuring the network and messaging layer.")
-        network_group.add_argument("-c", "--cluster-node", dest="cluster_node", help="IP address or hostname of existing cluster node", metavar="HOST")
-        network_group.add_argument("-i", "--interface", dest="nic_list", metavar="IF", action="append", choices=utils.interface_choice(), default=[],
+        network_group.add_argument(
+            "-c", "--cluster-node", metavar="[USER@]HOST", dest="cluster_node",
+            help="User and host to login to an existing cluster node. The host can be specified with either a hostname or an IP.",
+        )
+        network_group.add_argument("-i", "--interface", dest="nic_list", metavar="IF", action=CustomAppendAction, choices=utils.interface_choice(), default=[],
                 help="Bind to IP address on interface IF. Use -i second time for second interface")
         options, args = parse_options(parser, args)
         if options is None or args is None:
@@ -474,7 +602,7 @@ the config.core.force option.""",
         '''
         Rename the cluster.
         '''
-        if not utils.service_is_active("corosync.service"):
+        if not ServiceManager(sh.ClusterShellAdaptorForLocalShell(sh.LocalShell())).service_is_active("corosync.service"):
             context.fatal_error("Can't rename cluster when cluster service is stopped")
         old_name = cib_factory.get_property('cluster-name')
         if old_name and new_name == old_name:
@@ -548,7 +676,10 @@ Cluster Description
         parser.add_argument("-h", "--help", action="store_true", dest="help", help="Show this help message")
         parser.add_argument("-q", "--quiet", help="Be quiet (don't describe what's happening, just do it)", action="store_true", dest="quiet")
         parser.add_argument("-y", "--yes", help='Answer "yes" to all prompts (use with caution)', action="store_true", dest="yes_to_all")
-        parser.add_argument("-a", "--arbitrator", help="IP address of geo cluster arbitrator", dest="arbitrator", metavar="IP")
+        parser.add_argument(
+            "-a", "--arbitrator", dest="arbitrator", metavar="[USER@]HOST",
+            help="Geo cluster arbitrator",
+        )
         parser.add_argument("-s", "--clusters", help="Geo cluster description (see details below)", dest="clusters", metavar="DESC")
         parser.add_argument("-t", "--tickets", help="Tickets to create (space-separated)", dest="tickets", metavar="LIST")
         options, args = parse_options(parser, args)
@@ -600,7 +731,7 @@ an existing cluster.""",
         parser.add_argument("-h", "--help", action="store_true", dest="help", help="Show this help message")
         parser.add_argument("-q", "--quiet", help="Be quiet (don't describe what's happening, just do it)", action="store_true", dest="quiet")
         parser.add_argument("-y", "--yes", help='Answer "yes" to all prompts (use with caution)', action="store_true", dest="yes_to_all")
-        parser.add_argument("-c", "--cluster-node", help="IP address of an already-configured geo cluster or arbitrator", dest="cluster_node", metavar="IP")
+        parser.add_argument("-c", "--cluster-node", metavar="[USER@]HOST", help="An already-configured geo cluster or arbitrator", dest="cluster_node")
         parser.add_argument("-s", "--clusters", help="Geo cluster description (see geo-init for details)", dest="clusters", metavar="DESC")
         options, args = parse_options(parser, args)
         if options is None or args is None:
@@ -638,7 +769,9 @@ to get the geo cluster configuration.""",
         parser.add_argument("-h", "--help", action="store_true", dest="help", help="Show this help message")
         parser.add_argument("-q", "--quiet", help="Be quiet (don't describe what's happening, just do it)", action="store_true", dest="quiet")
         parser.add_argument("-y", "--yes", help='Answer "yes" to all prompts (use with caution)', action="store_true", dest="yes_to_all")
-        parser.add_argument("-c", "--cluster-node", help="IP address of an already-configured geo cluster", dest="cluster_node", metavar="IP")
+        parser.add_argument("-c", "--cluster-node", metavar="[USER@]HOST", help="An already-configured geo cluster", dest="cluster_node")
+        parser.add_argument('--use-ssh-agent', action='store_true', dest='use_ssh_agent',
+                            help="Use an existing key from ssh-agent instead of creating new key pairs")
         options, args = parse_options(parser, args)
         if options is None or args is None:
             return
@@ -676,7 +809,7 @@ to get the geo cluster configuration.""",
             else:
                 print("%-16s unknown" % (svc))
 
-        rc, outp = utils.get_stdout(['corosync-cfgtool', '-s'], shell=False)
+        rc, outp = ShellUtils().get_stdout(['corosync-cfgtool', '-s'], shell=False)
         if rc == 0:
             print("")
             print(outp)
@@ -702,15 +835,6 @@ to get the geo cluster configuration.""",
         '''
         Execute the given command on all nodes/specific node(s), report outcome
         '''
-        try:
-            import parallax
-            _has_parallax = True
-        except ImportError:
-            _has_parallax = False
-
-        if not _has_parallax:
-            context.fatal_error("python package parallax is needed for this command")
-
         if nodes:
             hosts = list(nodes)
         else:
@@ -718,18 +842,20 @@ to get the geo cluster configuration.""",
             if hosts is None:
                 context.fatal_error("failed to get node list from cluster")
 
-        for host, result in crmsh.parallax.parallax_run(hosts, cmd).items():
-            if isinstance(result, parallax.Error):
+        for host, result in prun.prun({x: cmd for x in hosts}).items():
+            if isinstance(result, prun.PRunError):
                 logger.error("[%s]: %s", host, result)
             else:
-                rc, stdout, stderr = result
-                if rc != 0:
-                    logger.error("[%s]: rc=%s\n%s\n%s", host, rc, utils.to_ascii(stdout), utils.to_ascii(stderr))
+                if result.returncode != 0:
+                    logger.error(
+                        "[%s]: Exited with error code %s. Error output: %s",
+                        host, result.returncode, utils.to_ascii(result.stderr),
+                    )
                 else:
-                    if not stdout:
-                        logger.info("[%s]" % host)
+                    if not result.stdout:
+                        logger.info("[%s]", host)
                     else:
-                        logger.info("[%s]\n%s" % (host, utils.to_ascii(stdout)))
+                        logger.info("[%s]\n%s", host, utils.to_ascii(result.stdout))
 
     def do_copy(self, context, local_file, *nodes):
         '''
