@@ -84,12 +84,8 @@ class Context(object):
             if cmd:
                 utils.check_user_access(self.current_level().name)
                 rv = self.execute_command() is not False
-        except (ValueError, IOError) as msg:
-            if config.core.debug or options.regression_tests:
-                import traceback
-                traceback.print_exc()
-                sys.stdout.flush()
-            logger.error("%s: %s", self.get_qualified_name(), msg)
+        except (ValueError, IOError) as e:
+            logger.error("%s: %s", self.get_qualified_name(), e, exc_info=e)
             rv = False
         except utils.TerminateSubCommand:
             return False
@@ -97,7 +93,7 @@ class Context(object):
             rv = self._back_out() and rv
 
         # wait for dc if wait flag set
-        if rv and self._wait_for_dc:
+        if self._wait_for_dc:
             return utils.wait4dc(self.command_name, not options.batch)
         return rv
 
@@ -271,7 +267,7 @@ class Context(object):
         rv = self.command_info.function(*arglist)
 
         # should we wait till the command takes effect?
-        if rv and self.should_wait():
+        if self.should_wait():
             self._wait_for_dc = True
         return rv
 
