@@ -8,15 +8,16 @@ from lxml import etree, doctestcompare
 import copy
 import bz2
 from collections import defaultdict
+from tempfile import mktemp
 
-from . import config
+from . import config, sh
 from . import options
 from . import schema
 from . import constants
 from . import userdir
-from tempfile import mktemp
+from .sh import ShellUtils
 from .utils import add_sudo, str2file, str2tmp, get_boolean, handle_role_for_ocf_1_1, copy_local_file, rmfile
-from .utils import get_stdout, get_stdout_or_raise_error, stdout2list, crm_msec, crm_time_cmp
+from .utils import stdout2list, crm_msec, crm_time_cmp
 from .utils import olist, get_cib_in_use, get_tempdir, to_ascii, is_boolean_true
 from . import log
 
@@ -234,16 +235,6 @@ class RscState(object):
         except (IndexError, AttributeError):
             return None
 
-    def has_rsc_stickiness(self):
-        """
-        Check if resource-stickiness already set
-        """
-        self._init_cib()
-        if self.rsc_dflt_elem is None:
-            return False
-        attr = get_attr_in_set(self.rsc_dflt_elem, "resource-stickiness")
-        return attr is not None
-
     def is_ms_or_promotable_clone(self, ident):
         '''
         Test if the resource is master-slave.
@@ -303,7 +294,7 @@ class RscState(object):
         if not is_live_cib():
             return False
         test_id = self.rsc_clone(ident) or ident
-        rc, outp = get_stdout(self.rsc_status % test_id, stderr_on=False)
+        rc, outp = ShellUtils().get_stdout(self.rsc_status % test_id, stderr_on=False)
         return outp.find("running") > 0 and outp.find("NOT") == -1
 
     def is_group(self, ident):
@@ -1524,59 +1515,61 @@ class CrmMonXmlParser(object):
         Init function
         when peer set, parse peer node's results
         """
-        self.xml_elem = None
         self.peer = peer
+        self.xml_elem = self._load()
 
     def _load(self):
         """
         Load xml output of crm_mon
         """
-        output = get_stdout_or_raise_error(constants.CRM_MON_XML_OUTPUT, remote=self.peer, no_raise=True)
-        self.xml_elem = text2elem(output)
+        _, output, _ = sh.cluster_shell().get_rc_stdout_stderr_without_input(self.peer, constants.CRM_MON_XML_OUTPUT)
+        return text2elem(output)
 
-    @classmethod
-    def is_node_online(cls, node):
+    def is_node_online(self, node):
         """
-        Check if node online
+        Check if a node is online
         """
-        cls_inst = cls()
-        cls_inst._load()
-        elem_list = cls_inst.xml_elem.xpath('//node[@name="{}" and @online="true"]'.format(node))
-        return len(elem_list) != 0
+        xpath = f'//node[@name="{node}" and @online="true"]'
+        return bool(self.xml_elem.xpath(xpath))
 
-    @classmethod
-    def is_resource_configured(cls, ra_type, peer=None):
+    def get_node_list(self, attr=None):
         """
-        Check if the RA configured
+        Get a list of nodes based on the given attribute
         """
-        cls_inst = cls(peer=peer)
-        cls_inst._load()
-        elem_list = cls_inst.xml_elem.xpath('//resource[@resource_agent="{}"]'.format(ra_type))
-        return len(elem_list) != 0
+        attr_dict = {
+            'standby': '[@standby="true"]',
+            'online': '[@standby="false"]'
+        }
+        xpath_str = f'//node{attr_dict.get(attr, "")}'
+        return [e.get('name') for e in self.xml_elem.xpath(xpath_str)]
 
-    @classmethod
-    def is_any_resource_running(cls, peer=None):
+    def is_resource_configured(self, ra_type):
+        """
+        Check if the RA is configured
+        """
+        xpath = f'//resource[@resource_agent="{ra_type}"]'
+        return bool(self.xml_elem.xpath(xpath))
+
+    def is_any_resource_running(self):
         """
         Check if any RA is running
         """
-        cls_inst = cls(peer=peer)
-        cls_inst._load()
-        elem_list = cls_inst.xml_elem.xpath('//resource[@active="true"]')
-        return len(elem_list) != 0
+        xpath = '//resource[@active="true"]'
+        return bool(self.xml_elem.xpath(xpath))
 
-    @classmethod
-    def is_resource_started(cls, ra, peer=None):
+    def is_resource_started(self, ra):
         """
         Check if the RA started(in all clone instances if configured as clone)
 
         @ra could be resource id or resource type
         """
-        cls_inst = cls(peer=peer)
-        cls_inst._load()
-        elem_list = cls_inst.xml_elem.xpath('//resource[(@id="{ra}" or @resource_agent="{ra}") and @active="true"]'.format(ra=ra))
-        # Stopped or not exist
-        if not elem_list:
-            return False
-        # Starting will return False
-        return all([True if elem.get('role') == 'Started' else False for elem in elem_list])
+        xpath = f'//resource[(@id="{ra}" or @resource_agent="{ra}") and @active="true" and @role="Started"]'
+        return bool(self.xml_elem.xpath(xpath))
+
+    def get_resource_id_list_via_type(self, ra_type):
+        """
+        Given configured ra type, get the ra id list
+        """
+        xpath = f'//resource[@resource_agent="{ra_type}"]'
+        return [elem.get('id') for elem in self.xml_elem.xpath(xpath)]
 # vim:ts=4:sw=4:et:
