@@ -69,7 +69,7 @@ optional arguments:
                         destructive, especially those storage related
                         configurations and stages.)
   -n NAME, --name NAME  Set the name of the configured cluster.
-  -N NODENAME, --node NODENAME
+  -N [USER@]HOST, --node [USER@]HOST
                         The member node of the cluster. Note: the current node
                         is always get initialized during bootstrap in the
                         beginning.
@@ -82,6 +82,8 @@ optional arguments:
   --no-overwrite-sshkey
                         Avoid "/root/.ssh/id_rsa" overwrite if "-y" option is
                         used (False by default; Deprecated)
+  --use-ssh-agent       Use an existing key from ssh-agent instead of creating
+                        new key pairs
 
 Network configuration:
   Options for configuring the network and messaging layer.
@@ -107,8 +109,9 @@ QDevice configuration:
   
   Options for configuring QDevice and QNetd.
 
-  --qnetd-hostname HOST
-                        HOST or IP of the QNetd server to be used
+  --qnetd-hostname [USER@]HOST
+                        User and host of the QNetd server. The host can be
+                        specified in either hostname or IP address.
   --qdevice-port PORT   TCP PORT of QNetd server (default:5403)
   --qdevice-algo ALGORITHM
                         QNetd decision ALGORITHM (ffsplit/lms,
@@ -191,6 +194,12 @@ Examples:
   # Add SBD on a running cluster
   crm cluster init sbd -s <share disk> -y
 
+  # Replace SBD device on a running cluster which already configured SBD
+  crm -F cluster init sbd -s <share disk> -y
+
+  # Add diskless SBD on a running cluster
+  crm cluster init sbd -S -y
+
   # Add QDevice on a running cluster
   crm cluster init qdevice --qnetd-hostname <qnetd addr> -y
 
@@ -213,12 +222,16 @@ optional arguments:
   -y, --yes             Answer "yes" to all prompts (use with caution)
   -w WATCHDOG, --watchdog WATCHDOG
                         Use the given watchdog device
+  --use-ssh-agent       Use an existing key from ssh-agent instead of creating
+                        new key pairs
 
 Network configuration:
   Options for configuring the network and messaging layer.
 
-  -c HOST, --cluster-node HOST
-                        IP address or hostname of existing cluster node
+  -c [USER@]HOST, --cluster-node [USER@]HOST
+                        User and host to login to an existing cluster node.
+                        The host can be specified with either a hostname or an
+                        IP.
   -i IF, --interface IF
                         Bind to IP address on interface IF. Use -i second time
                         for second interface
@@ -276,8 +289,8 @@ optional arguments:
   -h, --help            Show this help message
   -q, --quiet           Be quiet (don't describe what's happening, just do it)
   -y, --yes             Answer "yes" to all prompts (use with caution)
-  -a IP, --arbitrator IP
-                        IP address of geo cluster arbitrator
+  -a [USER@]HOST, --arbitrator [USER@]HOST
+                        Geo cluster arbitrator
   -s DESC, --clusters DESC
                         Geo cluster description (see details below)
   -t LIST, --tickets LIST
@@ -316,9 +329,8 @@ optional arguments:
   -h, --help            Show this help message
   -q, --quiet           Be quiet (don't describe what's happening, just do it)
   -y, --yes             Answer "yes" to all prompts (use with caution)
-  -c IP, --cluster-node IP
-                        IP address of an already-configured geo cluster or
-                        arbitrator
+  -c [USER@]HOST, --cluster-node [USER@]HOST
+                        An already-configured geo cluster or arbitrator
   -s DESC, --clusters DESC
                         Geo cluster description (see geo-init for details)'''
 
@@ -335,5 +347,7 @@ optional arguments:
   -h, --help            Show this help message
   -q, --quiet           Be quiet (don't describe what's happening, just do it)
   -y, --yes             Answer "yes" to all prompts (use with caution)
-  -c IP, --cluster-node IP
-                        IP address of an already-configured geo cluster'''
+  -c [USER@]HOST, --cluster-node [USER@]HOST
+                        An already-configured geo cluster
+  --use-ssh-agent       Use an existing key from ssh-agent instead of creating
+                        new key pairs'''
