@@ -63,7 +63,7 @@ def test_query_qdevice_status_exception(mock_configured):
 
 
 @mock.patch('crmsh.utils.print_cluster_nodes')
-@mock.patch('crmsh.utils.get_stdout_or_raise_error')
+@mock.patch('crmsh.sh.ClusterShell.get_stdout_or_raise_error')
 @mock.patch('crmsh.utils.is_qdevice_configured')
 def test_query_qdevice_status(mock_configured, mock_run, mock_print):
     mock_configured.return_value = True
@@ -96,7 +96,7 @@ def test_query_status_except():
     assert str(err.value) == "Wrong type \"xxx\" to query status"
 
 
-@mock.patch("crmsh.utils.get_stdout_stderr")
+@mock.patch("crmsh.sh.ShellUtils.get_stdout_stderr")
 def test_query_ring_status_except(mock_run):
     mock_run.return_value = (1, None, "error")
     with pytest.raises(ValueError) as err:
@@ -105,7 +105,7 @@ def test_query_ring_status_except(mock_run):
     mock_run.assert_called_once_with("corosync-cfgtool -s")
 
 
-@mock.patch("crmsh.utils.get_stdout_stderr")
+@mock.patch("crmsh.sh.ShellUtils.get_stdout_stderr")
 def test_query_ring_status(mock_run):
     mock_run.return_value = (0, "data", None)
     corosync.query_ring_status()
@@ -113,7 +113,7 @@ def test_query_ring_status(mock_run):
 
 
 @mock.patch("crmsh.utils.print_cluster_nodes")
-@mock.patch("crmsh.utils.get_stdout_stderr")
+@mock.patch("crmsh.sh.ShellUtils.get_stdout_stderr")
 def test_query_quorum_status_except(mock_run, mock_print_nodes):
     mock_run.return_value = (1, None, "error")
     with pytest.raises(ValueError) as err:
@@ -124,7 +124,7 @@ def test_query_quorum_status_except(mock_run, mock_print_nodes):
 
 
 @mock.patch("crmsh.utils.print_cluster_nodes")
-@mock.patch("crmsh.utils.get_stdout_stderr")
+@mock.patch("crmsh.sh.ShellUtils.get_stdout_stderr")
 def test_query_quorum_status(mock_run, mock_print_nodes):
     mock_run.return_value = (0, "data", None)
     corosync.query_quorum_status()
@@ -133,7 +133,7 @@ def test_query_quorum_status(mock_run, mock_print_nodes):
 
 
 @mock.patch("crmsh.utils.print_cluster_nodes")
-@mock.patch("crmsh.utils.get_stdout_stderr")
+@mock.patch("crmsh.sh.ShellUtils.get_stdout_stderr")
 def test_query_quorum_status_no_quorum(mock_run, mock_print_nodes):
     mock_run.return_value = (2, "no quorum", None)
     corosync.query_quorum_status()
@@ -270,7 +270,7 @@ def test_get_corosync_value_dict(mock_get_value):
 
 
 @mock.patch('crmsh.corosync.get_value')
-@mock.patch('crmsh.utils.get_stdout_or_raise_error')
+@mock.patch('crmsh.sh.ClusterShell.get_stdout_or_raise_error')
 def test_get_corosync_value_raise(mock_run, mock_get_value):
     mock_run.side_effect = ValueError
     mock_get_value.return_value = None
@@ -279,7 +279,7 @@ def test_get_corosync_value_raise(mock_run, mock_get_value):
     mock_get_value.assert_called_once_with("xxx")
 
 
-@mock.patch('crmsh.utils.get_stdout_or_raise_error')
+@mock.patch('crmsh.sh.ClusterShell.get_stdout_or_raise_error')
 def test_get_corosync_value(mock_run):
     mock_run.return_value = "totem.token = 10000"
     assert corosync.get_corosync_value("totem.token") == "10000"
@@ -308,10 +308,6 @@ class TestCorosyncParser(unittest.TestCase):
         _valid(p)
         self.assertEqual(p.get('bananas'), '5')
 
-    def test_logfile(self):
-        self.assertEqual(corosync.logfile(F1), '/var/log/cluster/corosync.log')
-        self.assertEqual(corosync.logfile('# nothing\n'), None)
-
     def test_udpu(self):
         p = Parser(F2)
         _valid(p)
