@@ -44,9 +44,9 @@ class TestCheck(TestCase):
         mock_hostname.assert_called_once_with()
         mock_task_inst.error.assert_called_once_with('Hostname "node1" is unresolvable.\n  Please add an entry to /etc/hosts or configure DNS.')
 
-    @mock.patch('crmsh.crash_test.check.crmshutils.service_is_active')
-    @mock.patch('crmsh.crash_test.check.crmshutils.service_is_enabled')
-    @mock.patch('crmsh.crash_test.check.crmshutils.service_is_available')
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_active')
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_enabled')
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_available')
     @mock.patch('crmsh.crash_test.task.TaskCheck')
     def test_check_time_service_none(self, mock_task, mock_service_available, mock_service_enabled, mock_service_active):
         mock_task_inst = mock.Mock()
@@ -65,9 +65,9 @@ class TestCheck(TestCase):
             ])
         mock_task_inst.warn.assert_called_once_with("No NTP service found.")
 
-    @mock.patch('crmsh.crash_test.check.crmshutils.service_is_active')
-    @mock.patch('crmsh.crash_test.check.crmshutils.service_is_enabled')
-    @mock.patch('crmsh.crash_test.check.crmshutils.service_is_available')
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_active')
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_enabled')
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_available')
     @mock.patch('crmsh.crash_test.task.TaskCheck')
     def test_check_time_service_warn(self, mock_task, mock_service_available, mock_service_enabled, mock_service_active):
         mock_task_inst = mock.Mock()
@@ -88,9 +88,9 @@ class TestCheck(TestCase):
             mock.call("chronyd.service is not active"),
             ])
 
-    @mock.patch('crmsh.crash_test.check.crmshutils.service_is_active')
-    @mock.patch('crmsh.crash_test.check.crmshutils.service_is_enabled')
-    @mock.patch('crmsh.crash_test.check.crmshutils.service_is_available')
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_active')
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_enabled')
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_available')
     @mock.patch('crmsh.crash_test.task.TaskCheck')
     def test_check_time_service(self, mock_task, mock_service_available, mock_service_enabled, mock_service_active):
         mock_task_inst = mock.Mock()
@@ -111,7 +111,7 @@ class TestCheck(TestCase):
             mock.call("chronyd.service is active")
             ])
 
-    @mock.patch('crmsh.crash_test.check.crmshutils.get_stdout_stderr')
+    @mock.patch('crmsh.sh.ShellUtils.get_stdout_stderr')
     @mock.patch('crmsh.crash_test.utils.corosync_port_list')
     def test_check_port_open_return(self, mock_corosync_port, mock_run):
         mock_corosync_port.return_value = ["1234", "5678"]
@@ -134,7 +134,7 @@ class TestCheck(TestCase):
         mock_corosync_port.assert_called_once_with()
         task_inst.error.assert_called_once_with("Can not get corosync's port")
 
-    @mock.patch('crmsh.crash_test.check.crmshutils.get_stdout_stderr')
+    @mock.patch('crmsh.sh.ShellUtils.get_stdout_stderr')
     @mock.patch('crmsh.crash_test.utils.corosync_port_list')
     def test_check_port_open(self, mock_corosync_port, mock_run):
         mock_corosync_port.return_value = ["1234", "5678"]
@@ -170,7 +170,7 @@ class TestCheck(TestCase):
             ])
         mock_task_inst.warn.assert_called_once_with("Failed to detect firewall")
 
-    @mock.patch('crmsh.crash_test.check.crmshutils.service_is_active')
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_active')
     @mock.patch('crmsh.crash_test.check.crmshutils.package_is_installed')
     @mock.patch('crmsh.crash_test.task.TaskCheck')
     def test_check_firewall_warn(self, mock_task, mock_installed, mock_active):
@@ -189,7 +189,7 @@ class TestCheck(TestCase):
         mock_task_inst.warn.assert_called_once_with("firewalld.service is not active")
 
     @mock.patch('crmsh.crash_test.check.check_port_open')
-    @mock.patch('crmsh.crash_test.check.crmshutils.service_is_active')
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_active')
     @mock.patch('crmsh.crash_test.check.crmshutils.package_is_installed')
     @mock.patch('crmsh.crash_test.task.TaskCheck')
     def test_check_firewall(self, mock_task, mock_installed, mock_active, mock_check_port):
@@ -229,8 +229,8 @@ class TestCheck(TestCase):
         mock_check_nodes.assert_called_once_with()
         mock_check_resources.assert_called_once_with()
 
-    @mock.patch('crmsh.crash_test.check.crmshutils.service_is_active')
-    @mock.patch('crmsh.crash_test.check.crmshutils.service_is_enabled')
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_active')
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_enabled')
     @mock.patch('crmsh.crash_test.task.TaskCheck')
     def test_check_cluster_service_pacemaker_disable(self, mock_task, mock_enabled, mock_active):
         mock_task_inst = mock.Mock(passed=False)
@@ -259,8 +259,8 @@ class TestCheck(TestCase):
         mock_task_inst.info.assert_called_once_with("corosync.service is running")
         mock_task_inst.error.assert_called_once_with("pacemaker.service is not running!")
 
-    @mock.patch('crmsh.crash_test.check.crmshutils.service_is_active')
-    @mock.patch('crmsh.crash_test.check.crmshutils.service_is_enabled')
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_active')
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_enabled')
     @mock.patch('crmsh.crash_test.task.TaskCheck')
     def test_check_cluster_service(self, mock_task, mock_enabled, mock_active):
         mock_task_inst = mock.Mock(passed=True)
@@ -305,7 +305,7 @@ class TestCheck(TestCase):
         mock_fence_info.assert_called_once_with()
         mock_task_inst.warn.assert_called_once_with("stonith is disabled")
 
-    @mock.patch('crmsh.crash_test.check.crmshutils.get_stdout_stderr')
+    @mock.patch('crmsh.sh.ShellUtils.get_stdout_stderr')
     @mock.patch('crmsh.crash_test.utils.FenceInfo')
     @mock.patch('crmsh.crash_test.task.TaskCheck')
     def test_check_fencing_no_resources(self, mock_task, mock_fence_info, mock_run):
@@ -325,8 +325,8 @@ class TestCheck(TestCase):
         mock_task_inst.info.assert_called_once_with("stonith is enabled")
         mock_task_inst.warn.assert_called_once_with("No stonith resource configured!")
 
-    @mock.patch('crmsh.crash_test.check.crmshutils.service_is_active')
-    @mock.patch('crmsh.crash_test.check.crmshutils.get_stdout_stderr')
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_active')
+    @mock.patch('crmsh.sh.ShellUtils.get_stdout_stderr')
     @mock.patch('crmsh.crash_test.utils.FenceInfo')
     @mock.patch('crmsh.crash_test.task.TaskCheck')
     def test_check_fencing_has_warn(self, mock_task, mock_fence_info, mock_run, mock_active):
@@ -353,8 +353,8 @@ class TestCheck(TestCase):
             mock.call("sbd service is not running!")
             ])
 
-    @mock.patch('crmsh.crash_test.check.crmshutils.service_is_active')
-    @mock.patch('crmsh.crash_test.check.crmshutils.get_stdout_stderr')
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_active')
+    @mock.patch('crmsh.sh.ShellUtils.get_stdout_stderr')
     @mock.patch('crmsh.crash_test.utils.FenceInfo')
     @mock.patch('crmsh.crash_test.task.TaskCheck')
     def test_check_fencing(self, mock_task, mock_fence_info, mock_run, mock_active):
@@ -380,7 +380,7 @@ class TestCheck(TestCase):
             ])
         mock_active.assert_called_once_with("sbd")
 
-    @mock.patch('crmsh.crash_test.check.crmshutils.get_stdout_stderr')
+    @mock.patch('crmsh.sh.ShellUtils.get_stdout_stderr')
     @mock.patch('crmsh.crash_test.task.TaskCheck')
     def test_check_nodes_error(self, mock_task, mock_run):
         mock_task_inst = mock.Mock()
@@ -395,7 +395,7 @@ class TestCheck(TestCase):
         mock_run.assert_called_once_with("crm_mon -1")
         mock_task_inst.error.assert_called_once_with("run \"crm_mon -1\" error: error data")
 
-    @mock.patch('crmsh.crash_test.check.crmshutils.get_stdout_stderr')
+    @mock.patch('crmsh.sh.ShellUtils.get_stdout_stderr')
     @mock.patch('crmsh.crash_test.task.TaskCheck')
     def test_check_nodes(self, mock_task, mock_run):
         mock_task_inst = mock.Mock()
@@ -428,7 +428,7 @@ Node List:
             ])
         mock_task_inst.warn.assert_called_once_with("OFFLINE nodes: [ 15sp2-2 ]")
 
-    @mock.patch('crmsh.crash_test.check.crmshutils.get_stdout_stderr')
+    @mock.patch('crmsh.sh.ShellUtils.get_stdout_stderr')
     @mock.patch('crmsh.crash_test.task.TaskCheck')
     def test_check_nodes_warn(self, mock_task, mock_run):
         mock_task_inst = mock.Mock()
@@ -545,7 +545,7 @@ Active Resources:
     @mock.patch('crmsh.crash_test.task.TaskCheck.print_result')
     @mock.patch('crmsh.crash_test.utils.is_valid_sbd')
     @mock.patch('crmsh.crash_test.utils.msg_info')
-    @mock.patch('crmsh.utils.get_stdout_stderr')
+    @mock.patch('crmsh.sh.ShellUtils.get_stdout_stderr')
     @mock.patch('crmsh.utils.parse_sysconfig')
     @mock.patch('os.path.exists')
     def test_check_sbd_exist_and_valid(cls, mock_os_path_exists,
@@ -570,7 +570,7 @@ Active Resources:
     @mock.patch('crmsh.crash_test.utils.find_candidate_sbd')
     @mock.patch('crmsh.crash_test.utils.is_valid_sbd')
     @mock.patch('crmsh.crash_test.utils.msg_warn')
-    @mock.patch('crmsh.utils.get_stdout_stderr')
+    @mock.patch('crmsh.sh.ShellUtils.get_stdout_stderr')
     @mock.patch('crmsh.utils.parse_sysconfig')
     @mock.patch('os.path.exists')
     def test_check_sbd_exist_and_not_valid_but_no_can(cls, mock_os_path_exists,
@@ -601,7 +601,7 @@ Active Resources:
     @mock.patch('crmsh.crash_test.utils.is_valid_sbd')
     @mock.patch('crmsh.crash_test.utils.msg_info')
     @mock.patch('crmsh.crash_test.utils.msg_warn')
-    @mock.patch('crmsh.utils.get_stdout_stderr')
+    @mock.patch('crmsh.sh.ShellUtils.get_stdout_stderr')
     @mock.patch('crmsh.utils.parse_sysconfig')
     @mock.patch('os.path.exists')
     def test_check_sbd_exist_and_not_exist_has_can(cls, mock_os_path_exists,
@@ -633,7 +633,7 @@ Active Resources:
     @mock.patch('crmsh.crash_test.utils.is_valid_sbd')
     @mock.patch('crmsh.crash_test.utils.msg_info')
     @mock.patch('crmsh.crash_test.utils.msg_warn')
-    @mock.patch('crmsh.utils.get_stdout_stderr')
+    @mock.patch('crmsh.sh.ShellUtils.get_stdout_stderr')
     @mock.patch('crmsh.utils.parse_sysconfig')
     @mock.patch('os.path.exists')
     def test_check_sbd_exist_and_not_valid_has_can(cls, mock_os_path_exists,
