@@ -38,32 +38,30 @@ def test_evaluate_qdevice_quorum_effect_reload(mock_get_dict, mock_quorate):
     mock_quorate.assert_called_once_with(3, 2)
 
 
-@mock.patch('crmsh.xmlutil.CrmMonXmlParser.is_any_resource_running')
+@mock.patch('crmsh.xmlutil.CrmMonXmlParser')
 @mock.patch('crmsh.utils.calculate_quorate_status')
 @mock.patch('crmsh.utils.get_quorum_votes_dict')
-def test_evaluate_qdevice_quorum_effect_later(mock_get_dict, mock_quorate, mock_ra_running):
+def test_evaluate_qdevice_quorum_effect_later(mock_get_dict, mock_quorate, mock_parser):
     mock_get_dict.return_value = {'Expected': '2', 'Total': '2'}
     mock_quorate.return_value = False
-    mock_ra_running.return_value = True
+    mock_parser().is_any_resource_running.return_value = True
     res = qdevice.evaluate_qdevice_quorum_effect(qdevice.QDEVICE_REMOVE)
     assert res == qdevice.QdevicePolicy.QDEVICE_RESTART_LATER
     mock_get_dict.assert_called_once_with()
     mock_quorate.assert_called_once_with(2, 1)
-    mock_ra_running.assert_called_once_with()
 
 
-@mock.patch('crmsh.xmlutil.CrmMonXmlParser.is_any_resource_running')
+@mock.patch('crmsh.xmlutil.CrmMonXmlParser')
 @mock.patch('crmsh.utils.calculate_quorate_status')
 @mock.patch('crmsh.utils.get_quorum_votes_dict')
-def test_evaluate_qdevice_quorum_effect(mock_get_dict, mock_quorate, mock_ra_running):
+def test_evaluate_qdevice_quorum_effect(mock_get_dict, mock_quorate, mock_parser):
     mock_get_dict.return_value = {'Expected': '2', 'Total': '2'}
     mock_quorate.return_value = False
-    mock_ra_running.return_value = False
+    mock_parser().is_any_resource_running.return_value = False
     res = qdevice.evaluate_qdevice_quorum_effect(qdevice.QDEVICE_REMOVE)
     assert res == qdevice.QdevicePolicy.QDEVICE_RESTART
     mock_get_dict.assert_called_once_with()
     mock_quorate.assert_called_once_with(2, 1)
-    mock_ra_running.assert_called_once_with()
 
 
 @mock.patch('crmsh.lock.RemoteLock')
@@ -255,7 +253,9 @@ class TestQDevice(unittest.TestCase):
         excepted_err_string = "invalid ALGORITHM choice: '1' (choose from 'ffsplit', 'lms')"
         self.assertEqual(excepted_err_string, str(err.exception))
 
-    def test_check_qdevice_tie_breaker(self):
+    @mock.patch('crmsh.service_manager.ServiceManager.service_is_active')
+    def test_check_qdevice_tie_breaker(self, mock_is_active):
+        mock_is_active.return_value = False
         with self.assertRaises(ValueError) as err:
             qdevice.QDevice.check_qdevice_tie_breaker("1")
         excepted_err_string = "invalid qdevice tie_breaker(lowest/highest/valid_node_id)"
@@ -322,8 +322,8 @@ class TestQDevice(unittest.TestCase):
 
         mock_installed.assert_called_once_with("corosync-qnetd", remote_addr="10.10.10.123")
 
-    @mock.patch("crmsh.utils.get_stdout_or_raise_error")
-    @mock.patch("crmsh.utils.service_is_active")
+    @mock.patch("crmsh.sh.ClusterShell.get_stdout_or_raise_error")
+    @mock.patch("crmsh.service_manager.ServiceManager.service_is_active")
     @mock.patch("crmsh.utils.package_is_installed")
     def test_valid_qnetd_duplicated_with_qnetd_running(self, mock_installed, mock_is_active, mock_run):
         mock_installed.return_value = True
@@ -338,10 +338,10 @@ class TestQDevice(unittest.TestCase):
 
         mock_installed.assert_called_once_with("corosync-qnetd", remote_addr="10.10.10.123")
         mock_is_active.assert_called_once_with("corosync-qnetd", remote_addr="10.10.10.123")
-        mock_run.assert_called_once_with("corosync-qnetd-tool -l -c cluster1", remote="10.10.10.123")
+        mock_run.assert_called_once_with("corosync-qnetd-tool -l -c cluster1", "10.10.10.123")
 
-    @mock.patch("crmsh.utils.get_stdout_or_raise_error")
-    @mock.patch("crmsh.utils.service_is_active")
+    @mock.patch("crmsh.sh.ClusterShell.get_stdout_or_raise_error")
+    @mock.patch("crmsh.service_manager.ServiceManager.service_is_active")
     @mock.patch("crmsh.utils.package_is_installed")
     def test_valid_qnetd_duplicated_without_qnetd_running(self, mock_installed, mock_is_active, mock_run):
         mock_installed.return_value = True
@@ -355,24 +355,24 @@ class TestQDevice(unittest.TestCase):
 
         mock_installed.assert_called_once_with("corosync-qnetd", remote_addr="10.10.10.123")
         mock_is_active.assert_called_once_with("corosync-qnetd", remote_addr="10.10.10.123")
-        mock_run.assert_called_once_with("test -f /etc/corosync/qnetd/nssdb/cluster-hacluster1.crt", remote="10.10.10.123")
+        mock_run.assert_called_once_with("test -f /etc/corosync/qnetd/nssdb/cluster-hacluster1.crt", "10.10.10.123")
 
-    @mock.patch("crmsh.utils.enable_service")
+    @mock.patch("crmsh.service_manager.ServiceManager.enable_service")
     def test_enable_qnetd(self, mock_enable):
         self.qdevice_with_ip.enable_qnetd()
         mock_enable.assert_called_once_with("corosync-qnetd.service", remote_addr="10.10.10.123")
 
-    @mock.patch("crmsh.utils.disable_service")
+    @mock.patch("crmsh.service_manager.ServiceManager.disable_service")
     def test_disable_qnetd(self, mock_disable):
         self.qdevice_with_ip.disable_qnetd()
         mock_disable.assert_called_once_with("corosync-qnetd.service", remote_addr="10.10.10.123")
 
-    @mock.patch("crmsh.utils.start_service")
+    @mock.patch("crmsh.service_manager.ServiceManager.start_service")
     def test_start_qnetd(self, mock_start):
         self.qdevice_with_ip.start_qnetd()
         mock_start.assert_called_once_with("corosync-qnetd.service", remote_addr="10.10.10.123")
 
-    @mock.patch("crmsh.utils.stop_service")
+    @mock.patch("crmsh.service_manager.ServiceManager.stop_service")
     def test_stop_qnetd(self, mock_stop):
         self.qdevice_with_ip.stop_qnetd()
         mock_stop.assert_called_once_with("corosync-qnetd.service", remote_addr="10.10.10.123")
@@ -409,10 +409,10 @@ class TestQDevice(unittest.TestCase):
 
     @mock.patch("crmsh.qdevice.QDevice.log_only_to_file")
     @mock.patch("os.path.exists")
-    @mock.patch("crmsh.qdevice.QDevice._fetch_file_to_local")
+    @mock.patch("crmsh.parallax.parallax_slurp")
     @mock.patch("crmsh.qdevice.QDevice.qnetd_cacert_on_local", new_callable=mock.PropertyMock)
     def test_fetch_qnetd_crt_from_qnetd_exist(self, mock_qnetd_cacert_local,
-                                              mock_fetch, mock_exists, mock_log):
+                                              mock_parallax_slurp, mock_exists, mock_log):
         mock_qnetd_cacert_local.return_value = "/etc/corosync/qdevice/net/10.10.10.123/qnetd-cacert.crt"
         mock_exists.return_value = True
 
@@ -420,15 +420,15 @@ class TestQDevice(unittest.TestCase):
 
         mock_exists.assert_called_once_with(mock_qnetd_cacert_local.return_value)
         mock_qnetd_cacert_local.assert_called_once_with()
-        mock_fetch.assert_not_called()
+        mock_parallax_slurp.assert_not_called()
         mock_log.assert_not_called()
 
     @mock.patch("crmsh.qdevice.QDevice.log_only_to_file")
     @mock.patch("os.path.exists")
-    @mock.patch("crmsh.qdevice.QDevice._fetch_file_to_local")
+    @mock.patch("crmsh.parallax.parallax_slurp")
     @mock.patch("crmsh.qdevice.QDevice.qnetd_cacert_on_local", new_callable=mock.PropertyMock)
     def test_fetch_qnetd_crt_from_qnetd(self, mock_qnetd_cacert_local,
-                                        mock_fetch, mock_exists, mock_log):
+                                        mock_parallax_slurp, mock_exists, mock_log):
         mock_qnetd_cacert_local.return_value = "/etc/corosync/qdevice/net/10.10.10.123/qnetd-cacert.crt"
         mock_exists.return_value = False
 
@@ -437,12 +437,12 @@ class TestQDevice(unittest.TestCase):
         mock_exists.assert_called_once_with(mock_qnetd_cacert_local.return_value)
         mock_qnetd_cacert_local.assert_called_once_with()
         mock_log.assert_called_once_with("Step 2: Fetch qnetd-cacert.crt from 10.10.10.123")
-        mock_fetch.assert_called_once_with("10.10.10.123", "/etc/corosync/qnetd/nssdb/qnetd-cacert.crt", "/etc/corosync/qdevice/net/10.10.10.123")
+        mock_parallax_slurp.assert_called_once_with(["10.10.10.123"], "/etc/corosync/qdevice/net", "/etc/corosync/qnetd/nssdb/qnetd-cacert.crt")
 
     @mock.patch("crmsh.qdevice.QDevice.log_only_to_file")
     @mock.patch("crmsh.utils.list_cluster_nodes")
     @mock.patch("crmsh.utils.this_node")
-    @mock.patch("crmsh.qdevice.QDevice._copy_file_to_remote_host")
+    @mock.patch("crmsh.parallax.parallax_copy")
     def test_copy_qnetd_crt_to_cluster_one_node(self, mock_copy, mock_this_node, mock_list_nodes, mock_log):
         mock_this_node.return_value = "node1.com"
         mock_list_nodes.return_value = ["node1.com"]
@@ -457,7 +457,7 @@ class TestQDevice(unittest.TestCase):
     @mock.patch("crmsh.qdevice.QDevice.log_only_to_file")
     @mock.patch("crmsh.utils.list_cluster_nodes")
     @mock.patch("crmsh.utils.this_node")
-    @mock.patch("crmsh.qdevice.QDevice._copy_file_to_remote_host")
+    @mock.patch("crmsh.parallax.parallax_copy")
     @mock.patch("crmsh.qdevice.QDevice.qnetd_cacert_on_local", new_callable=mock.PropertyMock)
     @mock.patch("os.path.dirname")
     def test_copy_qnetd_crt_to_cluster(self, mock_dirname, mock_qnetd_cacert_local,
@@ -472,8 +472,8 @@ class TestQDevice(unittest.TestCase):
         mock_this_node.assert_called_once_with()
         mock_list_nodes.assert_called_once_with()
         mock_log.assert_called_once_with("Step 3: Copy exported qnetd-cacert.crt to ['node2.com']")
-        mock_copy.assert_called_once_with(mock_dirname.return_value, "node2.com",
-                                          "/etc/corosync/qdevice/net")
+        mock_copy.assert_called_once_with(["node2.com"], mock_dirname.return_value,
+                                          "/etc/corosync/qdevice/net", True)
 
     @mock.patch("crmsh.qdevice.QDevice.log_only_to_file")
     @mock.patch("crmsh.parallax.parallax_call")
@@ -494,7 +494,7 @@ class TestQDevice(unittest.TestCase):
                                           "corosync-qdevice-net-certutil -i -c {}".format(mock_qnetd_cacert_local.return_value))
 
     @mock.patch("crmsh.qdevice.QDevice.log_only_to_file")
-    @mock.patch("crmsh.utils.get_stdout_or_raise_error")
+    @mock.patch("crmsh.sh.ClusterShell.get_stdout_or_raise_error")
     def test_create_ca_request(self, mock_stdout_stderr, mock_log):
         mock_stdout_stderr.return_value = (0, None, None)
 
@@ -507,7 +507,7 @@ class TestQDevice(unittest.TestCase):
     @mock.patch("crmsh.qdevice.QDevice.log_only_to_file")
     @mock.patch("crmsh.qdevice.QDevice.qdevice_crq_on_qnetd", new_callable=mock.PropertyMock)
     @mock.patch("crmsh.qdevice.QDevice.qdevice_crq_on_local", new_callable=mock.PropertyMock)
-    @mock.patch("crmsh.qdevice.QDevice._copy_file_to_remote_host")
+    @mock.patch("crmsh.parallax.parallax_copy")
     def test_copy_crq_to_qnetd(self, mock_copy, mock_qdevice_crq_local,
                                mock_qdevice_crq_qnetd, mock_log):
         mock_qdevice_crq_local.return_value = "/etc/corosync/qdevice/net/nssdb/qdevice-net-node.crq"
@@ -516,8 +516,8 @@ class TestQDevice(unittest.TestCase):
         self.qdevice_with_ip.copy_crq_to_qnetd()
 
         mock_log.assert_called_once_with("Step 6: Copy qdevice-net-node.crq to 10.10.10.123")
-        mock_copy.assert_called_once_with(mock_qdevice_crq_local.return_value, "10.10.10.123",
-                                          mock_qdevice_crq_qnetd.return_value)
+        mock_copy.assert_called_once_with(["10.10.10.123"], mock_qdevice_crq_local.return_value,
+                                          mock_qdevice_crq_qnetd.return_value, False)
         mock_qdevice_crq_local.assert_called_once_with()
         mock_qdevice_crq_qnetd.assert_called_once_with()
 
@@ -539,8 +539,8 @@ class TestQDevice(unittest.TestCase):
 
     @mock.patch("crmsh.qdevice.QDevice.log_only_to_file")
     @mock.patch("crmsh.qdevice.QDevice.qnetd_cluster_crt_on_qnetd", new_callable=mock.PropertyMock)
-    @mock.patch("crmsh.qdevice.QDevice._fetch_file_to_local")
-    def test_fetch_cluster_crt_from_qnetd(self, mock_fetch, mock_crt_on_qnetd, mock_log):
+    @mock.patch("crmsh.parallax.parallax_slurp")
+    def test_fetch_cluster_crt_from_qnetd(self, mock_parallax_slurp, mock_crt_on_qnetd, mock_log):
         mock_crt_on_qnetd.return_value = "/etc/corosync/qnetd/nssdb/cluster-hacluster.crt"
 
         self.qdevice_with_ip.cluster_name = "hacluster"
@@ -548,10 +548,10 @@ class TestQDevice(unittest.TestCase):
 
         mock_log.assert_called_once_with("Step 8: Fetch cluster-hacluster.crt from 10.10.10.123")
         mock_crt_on_qnetd.assert_has_calls([mock.call(), mock.call()])
-        mock_fetch.assert_called_once_with("10.10.10.123", mock_crt_on_qnetd.return_value, "/etc/corosync/qdevice/net/10.10.10.123",)
+        mock_parallax_slurp.assert_called_once_with(["10.10.10.123"], "/etc/corosync/qdevice/net", mock_crt_on_qnetd.return_value)
 
     @mock.patch("crmsh.qdevice.QDevice.log_only_to_file")
-    @mock.patch("crmsh.utils.get_stdout_or_raise_error")
+    @mock.patch("crmsh.sh.ClusterShell.get_stdout_or_raise_error")
     @mock.patch("crmsh.qdevice.QDevice.qnetd_cluster_crt_on_local", new_callable=mock.PropertyMock)
     def test_import_cluster_crt(self, mock_crt_on_local, mock_stdout_stderr, mock_log):
         mock_crt_on_local.return_value = "/etc/corosync/qdevice/net/10.10.10.123/cluster-hacluster.crt"
@@ -566,7 +566,7 @@ class TestQDevice(unittest.TestCase):
     @mock.patch("crmsh.qdevice.QDevice.log_only_to_file")
     @mock.patch("crmsh.utils.list_cluster_nodes")
     @mock.patch("crmsh.utils.this_node")
-    @mock.patch("crmsh.qdevice.QDevice._copy_file_to_remote_host")
+    @mock.patch("crmsh.parallax.parallax_copy")
     def test_copy_p12_to_cluster_one_node(self, mock_copy, mock_this_node, mock_list_nodes, mock_log):
         mock_this_node.return_value = "node1.com"
         mock_list_nodes.return_value = ["node1.com"]
@@ -581,7 +581,7 @@ class TestQDevice(unittest.TestCase):
     @mock.patch("crmsh.qdevice.QDevice.log_only_to_file")
     @mock.patch("crmsh.utils.list_cluster_nodes")
     @mock.patch("crmsh.utils.this_node")
-    @mock.patch("crmsh.qdevice.QDevice._copy_file_to_remote_hosts")
+    @mock.patch("crmsh.parallax.parallax_copy")
     @mock.patch("crmsh.qdevice.QDevice.qdevice_p12_on_local", new_callable=mock.PropertyMock)
     def test_copy_p12_to_cluster(self, mock_p12_on_local,
                                        mock_copy, mock_this_node, mock_list_nodes, mock_log):
@@ -594,8 +594,8 @@ class TestQDevice(unittest.TestCase):
         mock_log.assert_called_once_with("Step 10: Copy qdevice-net-node.p12 to ['node2.com']")
         mock_this_node.assert_called_once_with()
         mock_list_nodes.assert_called_once_with()
-        mock_copy.assert_called_once_with(mock_p12_on_local.return_value, ["node2.com"],
-                                          mock_p12_on_local.return_value)
+        mock_copy.assert_called_once_with(["node2.com"], mock_p12_on_local.return_value,
+                                          mock_p12_on_local.return_value, False)
         mock_p12_on_local.assert_has_calls([mock.call(), mock.call()])
 
     @mock.patch("crmsh.qdevice.QDevice.log_only_to_file")
@@ -662,8 +662,8 @@ class TestQDevice(unittest.TestCase):
     @mock.patch("os.path.exists")
     @mock.patch("crmsh.qdevice.QDevice.qnetd_cacert_on_cluster", new_callable=mock.PropertyMock)
     @mock.patch("crmsh.qdevice.QDevice.qnetd_cacert_on_local", new_callable=mock.PropertyMock)
-    @mock.patch("crmsh.qdevice.QDevice._fetch_file_to_local")
-    def test_fetch_qnetd_crt_from_cluster_exist(self, mock_fetch, mock_qnetd_cacert_local,
+    @mock.patch("crmsh.parallax.parallax_slurp")
+    def test_fetch_qnetd_crt_from_cluster_exist(self, mock_parallax_slurp, mock_qnetd_cacert_local,
                                                 mock_qnetd_cacert_cluster, mock_exists, mock_log):
         mock_exists.return_value = True
         mock_qnetd_cacert_cluster.return_value = "/etc/corosync/qdevice/net/node1.com/qnetd-cacert.crt"
@@ -674,14 +674,14 @@ class TestQDevice(unittest.TestCase):
         mock_exists.assert_called_once_with(mock_qnetd_cacert_cluster.return_value)
         mock_qnetd_cacert_cluster.assert_called_once_with()
         mock_qnetd_cacert_local.assert_not_called()
-        mock_fetch.assert_not_called()
+        mock_parallax_slurp.assert_not_called()
 
     @mock.patch("crmsh.qdevice.QDevice.log_only_to_file")
     @mock.patch("os.path.exists")
     @mock.patch("crmsh.qdevice.QDevice.qnetd_cacert_on_cluster", new_callable=mock.PropertyMock)
     @mock.patch("crmsh.qdevice.QDevice.qnetd_cacert_on_local", new_callable=mock.PropertyMock)
-    @mock.patch("crmsh.qdevice.QDevice._fetch_file_to_local")
-    def test_fetch_qnetd_crt_from_cluster(self, mock_fetch, mock_qnetd_cacert_local,
+    @mock.patch("crmsh.parallax.parallax_slurp")
+    def test_fetch_qnetd_crt_from_cluster(self, mock_parallax_slurp, mock_qnetd_cacert_local,
                                           mock_qnetd_cacert_cluster, mock_exists, mock_log):
         mock_exists.return_value = False
         mock_qnetd_cacert_cluster.return_value = "/etc/corosync/qdevice/net/node1.com/qnetd-cacert.crt"
@@ -693,10 +693,10 @@ class TestQDevice(unittest.TestCase):
         mock_exists.assert_called_once_with(mock_qnetd_cacert_cluster.return_value)
         mock_qnetd_cacert_cluster.assert_called_once_with()
         mock_qnetd_cacert_local.assert_called_once_with()
-        mock_fetch.assert_called_once_with("node1.com", mock_qnetd_cacert_local.return_value, '/etc/corosync/qdevice/net/node1.com')
+        mock_parallax_slurp.assert_called_once_with(["node1.com"], "/etc/corosync/qdevice/net", mock_qnetd_cacert_local.return_value)
 
     @mock.patch("crmsh.qdevice.QDevice.log_only_to_file")
-    @mock.patch("crmsh.utils.get_stdout_or_raise_error")
+    @mock.patch("crmsh.sh.ClusterShell.get_stdout_or_raise_error")
     @mock.patch("crmsh.qdevice.QDevice.qnetd_cacert_on_cluster", new_callable=mock.PropertyMock)
     def test_init_db_on_local(self, mock_qnetd_cacert_cluster, mock_stdout_stderr, mock_log):
         mock_qnetd_cacert_cluster.return_value = "/etc/corosync/qdevice/net/node1.com/qnetd-cacert.crt"
@@ -713,8 +713,8 @@ class TestQDevice(unittest.TestCase):
     @mock.patch("os.path.exists")
     @mock.patch("crmsh.qdevice.QDevice.qdevice_p12_on_cluster", new_callable=mock.PropertyMock)
     @mock.patch("crmsh.qdevice.QDevice.qdevice_p12_on_local", new_callable=mock.PropertyMock)
-    @mock.patch("crmsh.qdevice.QDevice._fetch_file_to_local")
-    def test_fetch_p12_from_cluster_exist(self, mock_fetch, mock_p12_on_local,
+    @mock.patch("crmsh.parallax.parallax_slurp")
+    def test_fetch_p12_from_cluster_exist(self, mock_parallax_slurp, mock_p12_on_local,
                                           mock_p12_on_cluster, mock_exists, mock_log):
         mock_exists.return_value = True
         mock_p12_on_cluster.return_value = "/etc/corosync/qdevice/net/node1.com/qdevice-net-node.p12"
@@ -725,14 +725,14 @@ class TestQDevice(unittest.TestCase):
         mock_exists.assert_called_once_with(mock_p12_on_cluster.return_value)
         mock_p12_on_cluster.assert_called_once_with()
         mock_p12_on_local.assert_not_called()
-        mock_fetch.assert_not_called()
+        mock_parallax_slurp.assert_not_called()
 
     @mock.patch("crmsh.qdevice.QDevice.log_only_to_file")
     @mock.patch("os.path.exists")
     @mock.patch("crmsh.qdevice.QDevice.qdevice_p12_on_cluster", new_callable=mock.PropertyMock)
     @mock.patch("crmsh.qdevice.QDevice.qdevice_p12_on_local", new_callable=mock.PropertyMock)
-    @mock.patch("crmsh.qdevice.QDevice._fetch_file_to_local")
-    def test_fetch_p12_from_cluster(self, mock_fetch, mock_p12_on_local,
+    @mock.patch("crmsh.parallax.parallax_slurp")
+    def test_fetch_p12_from_cluster(self, mock_parallax_slurp, mock_p12_on_local,
                                     mock_p12_on_cluster, mock_exists, mock_log):
         mock_exists.return_value = False
         mock_p12_on_cluster.return_value = "/etc/corosync/qdevice/net/node1.com/qdevice-net-node.p12"
@@ -744,10 +744,10 @@ class TestQDevice(unittest.TestCase):
         mock_exists.assert_called_once_with(mock_p12_on_cluster.return_value)
         mock_p12_on_cluster.assert_called_once_with()
         mock_p12_on_local.assert_called_once_with()
-        mock_fetch.assert_called_once_with("node1.com", mock_p12_on_local.return_value, "/etc/corosync/qdevice/net/node1.com")
+        mock_parallax_slurp.assert_called_once_with(["node1.com"], '/etc/corosync/qdevice/net', mock_p12_on_local.return_value)
 
     @mock.patch("crmsh.qdevice.QDevice.log_only_to_file")
-    @mock.patch("crmsh.utils.get_stdout_or_raise_error")
+    @mock.patch("crmsh.sh.ClusterShell.get_stdout_or_raise_error")
     @mock.patch("crmsh.qdevice.QDevice.qdevice_p12_on_cluster", new_callable=mock.PropertyMock)
     def test_import_p12_on_local(self, mock_p12_on_cluster, mock_stdout_stderr, mock_log):
         mock_p12_on_cluster.return_value = "/etc/corosync/qdevice/net/node1.com/qdevice-net-node.p12"
@@ -860,7 +860,7 @@ class TestQDevice(unittest.TestCase):
 
     @mock.patch('logging.Logger.warning')
     @mock.patch('crmsh.corosync.get_value')
-    @mock.patch('crmsh.utils.get_stdout_or_raise_error')
+    @mock.patch('crmsh.sh.ClusterShell.get_stdout_or_raise_error')
     def test_check_qdevice_vote(self, mock_run, mock_get_value, mock_warning):
         data = """
 Membership information
@@ -872,7 +872,7 @@ Membership information
         mock_run.return_value = data
         mock_get_value.return_value = "qnetd-node"
         qdevice.QDevice.check_qdevice_vote()
-        mock_run.assert_called_once_with("corosync-quorumtool -s", success_val_list=[0, 2])
+        mock_run.assert_called_once_with("corosync-quorumtool -s", success_exit_status={0, 2})
         mock_get_value.assert_called_once_with("quorum.device.net.host")
         mock_warning.assert_called_once_with("Qdevice's vote is 0, which simply means Qdevice can't talk to Qnetd(qnetd-node) for various reasons.")
 
@@ -1011,7 +1011,7 @@ Membership information
         qdevice.QDevice.remove_certification_files_on_qnetd()
         mock_configured.assert_called_once_with()
 
-    @mock.patch('crmsh.utils.get_stdout_or_raise_error')
+    @mock.patch('crmsh.sh.ClusterShell.get_stdout_or_raise_error')
     @mock.patch('crmsh.corosync.get_value')
     @mock.patch('crmsh.utils.is_qdevice_configured')
     def test_remove_certification_files_on_qnetd(self, mock_configured, mock_get_value, mock_run):
@@ -1027,5 +1027,5 @@ Membership information
         crq_file = "/etc/corosync/qnetd/nssdb/qdevice-net-node.crq.cluster1"
         crq_cmd = "test -f {crq_file} && rm -f {crq_file}".format(crq_file=crq_file)
         mock_run.assert_has_calls([
-            mock.call(crt_cmd, remote="qnetd-node"),
-            mock.call(crq_cmd, remote="qnetd-node")])
+            mock.call(crt_cmd, "qnetd-node"),
+            mock.call(crq_cmd, "qnetd-node")])
